Documentation
¶
Overview ¶
Package edgegrid provides the Akamai {OPEN} Edgegrid Authentication scheme
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Host string `ini:"host"`
ClientToken string `ini:"client_token"`
ClientSecret string `ini:"client_secret"`
AccessToken string `ini:"access_token"`
HeaderToSign []string `ini:"headers_to_sign"`
MaxBody int `ini:"max_body"`
Debug bool `ini:"debug"`
}
Config struct provides all the necessary fields to create authorization header, debug is optional
func InitConfig ¶
InitConfig initializes configuration file
Directories
¶
| Path | Synopsis |
|---|---|
|
Godeps
|
|
|
_workspace/src/github.com/go-ini/ini
Package ini provides INI file read and write functionality in Go.
|
Package ini provides INI file read and write functionality in Go. |
|
_workspace/src/github.com/sirupsen/logrus
Package logrus is a structured logger for Go, completely API compatible with the standard library logger.
|
Package logrus is a structured logger for Go, completely API compatible with the standard library logger. |
|
_workspace/src/github.com/stretchr/testify/assert
A set of comprehensive testing tools for use with the normal Go testing system.
|
A set of comprehensive testing tools for use with the normal Go testing system. |
Click to show internal directories.
Click to hide internal directories.